#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys

from openeye import oechem
from openeye import oedocking


def main(argv=[__name__]):
    if len(argv) != 3:
        oechem.OEThrow.Usage("%s <receptor> <ligand>" % argv[0])

    # @ <SNIPPET-SCORE-BOX-1>
    protein = oechem.OEGraphMol()
    imstr = oechem.oemolistream(argv[1])
    oechem.OEReadMolecule(imstr, protein)

    pose = oechem.OEGraphMol()
    imstr.open(argv[2])
    oechem.OEReadMolecule(imstr, pose)

    addbox = 4.0
    box = oedocking.OEBox()
    oedocking.OESetupBox(box, pose, addbox)

    oescore = oedocking.OEScore()
    oescore.Initialize(protein, box)
    # @ </SNIPPET-SCORE-BOX-1>


if __name__ == "__main__":
    sys.exit(main(sys.argv))
